@@ -344,7 +344,7 @@ class EventClassificationRule(models.Model):
     event_class=models.ForeignKey(EventClass,verbose_name="Event Class")
     name=models.CharField("Name",max_length=64)
     preference=models.IntegerField("Preference",1000)
-    drop_event=models.BooleanField("Drop Event",default=False)
+    action=models.CharField("Action",max_length=1,choices=[("A","Make Active"),("C","Close"),("D","Drop")],default="A")
     is_builtin=models.BooleanField("Is Builtin",default=False)
     
     def __unicode__(self):
@@ -358,13 +358,14 @@ class EventClassificationRule(models.Model):
     ## Python representation of data structure
     ##
     def _python_code(self):
-        s=["##","## %s"%self.name,"##"]
+        s=["from noc.fm.rules.classification import ClassificationRule,CLOSE_EVENT,DROP_EVENT"]
+        s+=["##","## %s"%self.name,"##"]
         s+=["class %s_Rule(ClassificationRule):"%rx_py_id.sub("_",self.name)]
         s+=["    name=\"%s\""%py_q(self.name)]
         s+=["    event_class=%s"%self.event_class.name.replace(" ","").replace("-","_")]
         s+=["    preference=%d"%self.preference]
-        if self.drop_event:
-            s+=["    drop_event=True"]
+        if self.action!="A":
+            s+=["    action=%s"%{"C":"CLOSE_EVENT","D":"DROP_EVENT"}[self.action]]
         s+=["    patterns=["]
         for p in self.eventclassificationre_set.all():
             s+=["        (r\"%s\",r\"%s\"),"%(py_q(p.left_re),py_q(p.right_re))]
@@ -382,6 +383,34 @@ class EventClassificationRE(models.Model):
     left_re=models.CharField("Left RE",max_length=256)
     right_re=models.CharField("Right RE",max_length=256)
 ##
+## Event Post Processing
+##
+class EventPostProcessingRule(models.Model):
+    class Meta:
+        verbose_name="Event Post-Processing Rule"
+        verbose_name_plural="Event Post-Processing Rules"
+    event_class=models.ForeignKey(EventClass,verbose_name="Event Class")
+    name=models.CharField("Name",max_length=64)
+    preference=models.IntegerField("Preference",default=1000)
+    is_active=models.BooleanField("Is Active",default=True)
+    description=models.TextField("Description",blank=True,null=True)
+    # Actions
+    change_priority=models.ForeignKey(EventPriority,verbose_name="Change Priority to",blank=True,null=True)
+    change_category=models.ForeignKey(EventCategory,verbose_name="Change Category to",blank=True,null=True)
+    action=models.CharField("Action",max_length=1,choices=[("A","Make Active"),("C","Close"),("D","Drop")],default="A")
+    def __unicode__(self):
+        return self.name
+##
+## Regular expressions to match event vars
+##
+class EventPostProcessingRE(models.Model):
+    class Meta:
+        verbose_name="Event Post-Processing RE"
+        verbose_name_plural="Event Post-Processing REs"
+    rule=models.ForeignKey(EventPostProcessingRule,verbose_name="Event Post-Processing Rule")
+    var_re=models.CharField("Var RE",max_length=256)
+    value_re=models.CharField("Value RE",max_length=256)
+##
 ## Event Correlation Rule
 ## Correlation rules are the PyKE statements
 ##
@@ -482,7 +511,7 @@ class Event(models.Model):
         if from_status is None:
             from_status=self.status
         if to_status is None:
-            to_status=self.self
+            to_status=self.status
         l=EventLog(event=self,timestamp=datetime.datetime.now(),from_status=from_status,to_status=to_status,message=msg)
         l.save()
 ##
@@ -534,6 +563,7 @@ class AppMenu(Menu):
             ("Event Categories",    "/admin/fm/eventcategory/",           "fm.change_eventcategory"),
             ("Event Priorities",    "/admin/fm/eventpriority/",           "fm.change_eventpriority"),
             ("Classification Rules","/admin/fm/eventclassificationrule/", "fm.change_eventclassificationrule"),
+            ("Post-Processing Rules", "/admin/fm/eventpostprocessingrule/", "fm.change_eventpostprocessingrule"),
             ("Correlation Rules",   "/admin/fm/eventcorrelationrule/",    "fm.change_eventcorrelationrule"),
         ])
     ]
