@@ -14,11 +14,11 @@ from django import forms
 
 from noc.ip.models import VRFGroup,VRF,IPv4BlockAccess,IPv4Block,IPv4Address
 from noc.peer.models import AS
-from noc.lib.render import render,render_success
+from noc.lib.render import render,render_success,render_failure
 from noc.lib.validators import is_rd,is_cidr,is_int,is_ipv4,is_fqdn
 from noc.lib.ip import normalize_prefix,contains
 from noc.settings import config
-import csv,cStringIO,datetime,subprocess
+import csv,cStringIO,datetime,subprocess,re
 
 ##
 ## VRF list
@@ -138,7 +138,9 @@ class AssignAddressForm(forms.Form):
         if not is_ipv4(self.cleaned_data["ip"]):
             raise forms.ValidationError("Invalid IP Address")
         return self.cleaned_data["ip"]
-    
+
+rx_url_cidr=re.compile(r"^.*/(\d+\.\d+\.\d+\.\d+/\d+)/$")
+
 def assign_address(request,vrf_id,ip=None):
     vrf=get_object_or_404(VRF,id=int(vrf_id))
     if ip:
@@ -167,12 +169,31 @@ def assign_address(request,vrf_id,ip=None):
                 address.description=form.cleaned_data["description"]
                 address.tt=form.cleaned_data["tt"]
             else:
+                # Check no duplicated IPs
+                if IPv4Address.objects.filter(vrf=vrf,ip=form.cleaned_data["ip"]).count()>0:
+                    return render_failure(request,"Duplicated IP address","Address %s is already present in VRF %s"%(form.cleaned_data["ip"],vrf.name))
                 address=IPv4Address(vrf=vrf,fqdn=form.cleaned_data["fqdn"],
                     ip=form.cleaned_data["ip"],description=form.cleaned_data["description"],
                     modified_by=request.user)
             address.save()
             return HttpResponseRedirect("/ip/%d/%s/"%(vrf.id,address.parent.prefix))
     else:
+        if "ip" not in initial:
+            # Try to calculate ip address from referer
+            referer=request.META.get("HTTP_REFERER",None)
+            if referer:
+                match=rx_url_cidr.match(referer)
+                if match and is_cidr(match.group(1)):
+                    block=match.group(1)
+                    # Find first free IP address
+                    from django.db import connection
+                    c=connection.cursor()
+                    c.execute("SELECT free_ip(%s,%s)",[vrf.id,block])
+                    ip=c.fetchall()[0][0]
+                    if ip:
+                        initial["ip"]=ip
+                    else:
+                        initial["ip"]="NO FREE IP"
         form=AssignAddressForm(initial=initial)
     return render(request,"ip/assign_address.html",{"vrf":vrf,"form":form,"p":p})
 ##
