@@ -20,7 +20,11 @@ class AppMenu(Menu):
         ("Setup", [
             ("Users",  "/admin/auth/user/",  "auth.change_user"),
             ("Groups", "/admin/auth/group/", "auth.change_group")
-        ])
+        ]),
+        ("Documentation", [
+            ("Administrator's Guide", "/static/doc/en/ag/html/index.html"),
+            ("User's Guide", "/static/doc/en/ug/html/index.html"),
+        ]),
     ]
 ##
 ## Load and register reports
